@@ -389,6 +389,8 @@ class AgentLifeCycle:
         if(args.config.is_ssh_enabled()):
             object._agent_run_options["remote_intervention_agent"]["volumes"] = {
                 args.config.config_path + "ssh/id_rsa": {"bind": "/root/.ssh/id_rsa", "mode": "rw"}}
+        if(args.config.is_audio_enabled()):
+            object._agent_run_options["remote_intervention_agent"]["devices"] = ["/dev/snd"]
         object._agent_run_options["kriya"] = object._agent_run_options["remote_intervention_agent"]
         object._agent_run_options["kriya_watchdog"] = {
             "command": "python3 /home/watchdog.py", "volumes": {
